@@ -1,4 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
 
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -16,10 +15,10 @@
 import copy
 
 from heat.common import template_format
-from heat.engine.resources import cloud_watch
 from heat.engine import resource
-from heat.engine import watchrule
+from heat.engine.resources import cloud_watch
 from heat.engine import scheduler
+from heat.engine import watchrule
 from heat.tests.common import HeatTestCase
 from heat.tests import utils
 
@@ -59,7 +58,7 @@ class CloudWatchAlarmTest(HeatTestCase):
         rsrc = cloud_watch.CloudWatchAlarm(resource_name,
                                            t['Resources'][resource_name],
                                            stack)
-        self.assertEqual(None, rsrc.validate())
+        self.assertIsNone(rsrc.validate())
         scheduler.TaskRunner(rsrc.create)()
         self.assertEqual((rsrc.CREATE, rsrc.COMPLETE), rsrc.state)
         return rsrc
@@ -131,20 +130,22 @@ class CloudWatchAlarmTest(HeatTestCase):
         self.m.ReplayAll()
         rsrc = self.create_alarm(t, stack, 'MEMAlarmHigh')
         scheduler.TaskRunner(rsrc.suspend)()
-        self.assertEqual(rsrc.state, (rsrc.SUSPEND, rsrc.COMPLETE))
+        self.assertEqual((rsrc.SUSPEND, rsrc.COMPLETE), rsrc.state)
+
+        self.ctx = utils.dummy_context()
 
         wr = watchrule.WatchRule.load(
-            None, watch_name="test_stack-MEMAlarmHigh")
+            self.ctx, watch_name="test_stack-MEMAlarmHigh")
 
-        self.assertEqual(wr.state, watchrule.WatchRule.SUSPENDED)
+        self.assertEqual(watchrule.WatchRule.SUSPENDED, wr.state)
 
         scheduler.TaskRunner(rsrc.resume)()
-        self.assertEqual(rsrc.state, (rsrc.RESUME, rsrc.COMPLETE))
+        self.assertEqual((rsrc.RESUME, rsrc.COMPLETE), rsrc.state)
 
         wr = watchrule.WatchRule.load(
-            None, watch_name="test_stack-MEMAlarmHigh")
+            self.ctx, watch_name="test_stack-MEMAlarmHigh")
 
-        self.assertEqual(wr.state, watchrule.WatchRule.NODATA)
+        self.assertEqual(watchrule.WatchRule.NODATA, wr.state)
 
         scheduler.TaskRunner(rsrc.delete)()
         self.m.VerifyAll()
