@@ -1,4 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
 
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -19,12 +18,12 @@ from testtools import skipIf
 from heat.common import exception
 from heat.common import template_format
 from heat.engine import clients
-from heat.engine import scheduler
 from heat.engine.resources.neutron import vpnservice
+from heat.engine import scheduler
 from heat.openstack.common.importutils import try_import
+from heat.tests.common import HeatTestCase
 from heat.tests import fakes
 from heat.tests import utils
-from heat.tests.common import HeatTestCase
 
 
 neutronclient = try_import('neutronclient.v2_0.client')
@@ -242,7 +241,7 @@ class VPNServiceTest(HeatTestCase):
         scheduler.TaskRunner(rsrc.create)()
         self.assertEqual('VPNService', rsrc.FnGetAtt('name'))
         self.assertEqual('My new VPN service', rsrc.FnGetAtt('description'))
-        self.assertEqual(True, rsrc.FnGetAtt('admin_state_up'))
+        self.assertIs(True, rsrc.FnGetAtt('admin_state_up'))
         self.assertEqual('rou123', rsrc.FnGetAtt('router_id'))
         self.assertEqual('sub123', rsrc.FnGetAtt('subnet_id'))
         self.m.VerifyAll()
@@ -410,7 +409,7 @@ class IPsecSiteConnectionTest(HeatTestCase):
         self.assertEqual(120, rsrc.FnGetAtt('dpd')['timeout'])
         self.assertEqual('secret', rsrc.FnGetAtt('psk'))
         self.assertEqual('bi-directional', rsrc.FnGetAtt('initiator'))
-        self.assertEqual(True, rsrc.FnGetAtt('admin_state_up'))
+        self.assertIs(True, rsrc.FnGetAtt('admin_state_up'))
         self.assertEqual('ike123', rsrc.FnGetAtt('ikepolicy_id'))
         self.assertEqual('ips123', rsrc.FnGetAtt('ipsecpolicy_id'))
         self.assertEqual('vpn123', rsrc.FnGetAtt('vpnservice_id'))
